#HW4utils
import os
import logging
import numpy as np
import tensorflow as tf
import matplotlib.pyplot as plt
import tensorflow as tf
from tensorflow import keras
from tensorflow.keras import datasets

#########################################################
#
# traing_curves - utility to plot training curves from history object
#
def training_curves(history):
    train_loss = history.history["loss"]
    val_loss = history.history["val_loss"]
    train_acc = history.history["accuracy"]
    val_acc = history.history["val_accuracy"]
    
    epochs = np.arange(1,len(train_loss) + 1)


    figure, axis = plt.subplots(1,2,figsize=(10,4))
    axis[0].plot(epochs, train_loss, "b--", label="p-training loss")
    axis[0].plot(epochs, val_loss, "b", label="validation loss")
    axis[0].set_title("p-Training and Validation Losses")
    axis[0].set_xlabel("Epochs")
    axis[0].set_ylabel("Loss")
    axis[0].legend()


    axis[1].plot(epochs, train_acc, "b--",label="p-training acc")
    axis[1].plot(epochs, val_acc, "b", label="validation acc")
    axis[1].set_title("p-Training and Validation accuracy")
    axis[1].set_xlabel("Epochs")
    axis[1].set_ylabel("Accuracy")
    axis[1].legend()

################################################
#
# set_tf_loglevel - Utility to set the TF's logging messages.
#                   setting logging.FATAL minimizes logging messages
#
def set_tf_loglevel(level):
    if level >= logging.FATAL:
        os.environ['TF_CPP_MIN_LOG_LEVEL'] = '3'
    if level >= logging.ERROR:
        os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'
    if level >= logging.WARNING:
        os.environ['TF_CPP_MIN_LOG_LEVEL'] = '1'
    else:
        os.environ['TF_CPP_MIN_LOG_LEVEL'] = '0'
    logging.getLogger('tensorflow').setLevel(level)

################################################
#
#load_fashion_mnist(train_split):
#     utility to load TF's fashion mnist dataset.  Function
#     loads the training and test data and then
#     splits the training data into p-training and validation datasets
#     using train_split.
#
#     The function returns 3 lists of length 2; ptraining_data, 
#     validation_data, and testing_data.  First element of the list
#     is numpy array with the sample's inputs.  The second element of
#     the list is numpy array with sample's targets.

def load_fashion_mnist(train_split):

    (x_train, y_train), (x_test, y_test) = datasets.fashion_mnist.load_data()

    x_train_n = np.array(x_train).astype("float32")/255
    x_train_n = x_train_n.reshape(60000,28*28)
    N,_ = x_train_n.shape
    Nptrain = np.ceil(N*train_split).astype("uint32")
    x_ptrain = x_train_n[:Nptrain]
    y_ptrain = y_train[:Nptrain]
    x_val    = x_train_n[Nptrain:]
    y_val    = y_train[Nptrain:]

    x_test_n = np.array(x_test).astype("float32")/255
    x_test_n = x_test_n.reshape(10000,28*28)
    ptraining_data = (x_ptrain,y_ptrain)
    validation_data = (x_val, y_val)
    testing_data = (x_test_n,y_test)

    return ptraining_data, validation_data, testing_data 
